import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts

Item
{
	Localizer { id:tr; scope:"ParentalControl" }
	property variant context: MainWindow.GetSubViewModel("ParentalControl")
	property variant commonFontStyles: Fonts.Common{}
	anchors.fill: parent
	objectName: "accountList"

	QtObject
	{
		id:style

		// style properties for item delegate
		property int itemHeight: 120
		property color itemColorFirst: "white"
		property color itemColorSecond: "#f0f0f0"
	}

    Widgets.ScrollBar
    {
        id:scrollbar
        target:		 accounts
        anchors.top:	accounts.top;
        anchors.bottom: accounts.bottom;
        anchors.right:  parent.right;
    }

	ListView
	{
		id: accounts
		objectName: "accounts"

        anchors
        {
            left: parent.left
            top: parent.top
            bottom: parent.bottom
            right: scrollbar.left
        }

		model: MainWindow.GetSubViewModel("ParentalControl").UserList
		delegate: itemDelegate
		orientation : "Vertical"
		currentIndex: 0;
		property int tabOrder: 1
		property int focusItemY

		function setNextPage(isForward)
		{
			var indexAtBegining = indexAt(1, contentY);
			if (currentItem)
				focusItemY = (height > currentItem.height/2) ? 
					Math.min(Math.max(currentItem.y - contentY, currentItem.height/2), height - currentItem.height/2) : height/2;

			var indexSetToBegin = isForward ? indexAt(1, contentY + height) : (indexAtBegining - Math.floor(height * count / contentHeight ))
			if (isForward && indexSetToBegin  == -1)
				return;
			if (indexSetToBegin < 0)
				indexSetToBegin = 0;
			else if ((indexSetToBegin >  indexAtBegining) == !isForward)
				indexSetToBegin = indexAtBegining;

			positionViewAtIndex(indexSetToBegin, ListView.Beginning);
			if (focusItemY >= 0)
				currentIndex = indexAt(1, contentY + focusItemY);
		}

		function onEnd()
		{
			positionViewAtEnd();
			currentIndex = count - 1;
		}

		function onHome()
		{
			positionViewAtBeginning();
			currentIndex = 0;
		}

		Keys.onPressed:
		{
			if (event.modifiers & (Qt.ShiftModifier | Qt.ControlModifier | Qt.AltModifier | Qt.MetaModifier))
			{
				event.accepted = false;
				return;
			}
			switch (event.key)
			{
				case Qt.Key_PageDown: setNextPage(true); break;
				case Qt.Key_PageUp: setNextPage(false); break;
				case Qt.Key_Home: onHome(); break;
				case Qt.Key_End: onEnd(); break;
				default: event.accepted = false;
			}
		}

		property int currentFocusColumnId: 1
		function focusColumnIdChanged(columnId)
		{
			if (currentFocusColumnId != columnId)
				currentFocusColumnId = columnId;
		}
	}

	Component
	{
		id: itemDelegate

		FocusScope
		{
			property int tabOrder: ((index == 0) && (ListView.view.currentIndex == 0)) ? 1 : 0
			id: focusScope
			anchors.left:parent.left
			anchors.right:parent.right
			height: style.itemHeight
			property QtObject account:model.modelData
			onActiveFocusChanged: if (activeFocus) ListView.view.currentIndex = index
			Rectangle
			{
				id:itemBody
				objectName: "itemBody"

				anchors.fill: parent
				color: style.itemColorFirst;
				Image
				{
					id:iconElement

					anchors.left:parent.left; anchors.leftMargin:32
					anchors.verticalCenter:parent.verticalCenter
					source: {
					return {"Mother":"../common/images/parental_control/avatar_girl_01.png",
							"SonMajor":"../common/images/parental_control/avatar_son.png",
							"DotherMajor":"../common/images/parental_control/avatar_daughter.png",
							"SonMinor":"../common/images/parental_control/avatar_son_jr.png",
							"DotherMinor":"../common/images/parental_control/avatar_daughter_jr.png",
							"Father":"../common/images/parental_control/avatar_man_01.png",
							"":"../common/images/parental_control/avatar_man_01.png"}[account.iconId];
					}
				}

				Item
				{
					anchors.left:iconElement.right;anchors.leftMargin: 16
					anchors.right:btnOnOff.left;anchors.rightMargin:20

					Widgets.StandardCaptionText
					{
						id:accountName
						anchors.left:parent.left
						anchors.top:parent.top;
						anchors.topMargin:32
						anchors.right: parent.right
						elide: Text.ElideRight
						text: account.name;
						horizontalAlignment: Text.AlignLeft
					}

					Row
					{
						anchors.left:parent.left;
						anchors.top:accountName.bottom;anchors.topMargin: 10
						spacing: 5

						Image
						{
							source: account.isControlEnabled ? "../common/images/parental_control/enabled.png" : "../common/images/parental_control/disabled.png"
							anchors.verticalCenter: parent.verticalCenter
						}

						Text
						{
							text: tr.Localize(account.isControlEnabled ? "ControlIsTurnedOn" : "ControlIsTurnedOff")
							color: account.isControlEnabled ? "#006a5d" : "#7b7b7b"
							anchors.verticalCenter: parent.verticalCenter
							anchors.verticalCenterOffset: -1
							font.pointSize: 10
						}
					}
				}				

				Widgets.GrayButton
				{
					id: settingsBtn
					property int columnId: 0
					setFocusOnPressed: true
					tabOrder: 0
					objectName: "ParCtlSettings" + index
					anchors.right:parent.right;anchors.rightMargin:32
					anchors.verticalCenter:parent.verticalCenter
					iconImage: "../images/parental_control/icons.png"
					onClicked: {account.settingsAction.Invoke()}
					KeyNavigation.left: btnOnOff
					onActiveFocusChanged: if (activeFocus) accounts.focusColumnIdChanged(columnId);
				}

				Widgets.GrayButton
				{
					id: btnOnOff
					property int columnId: 1
					setFocusOnPressed: true
					tabOrder: 0
					KeyNavigation.right: settingsBtn
					objectName: "rememberCheckBox" + index
					anchors.right: settingsBtn.left
					anchors.rightMargin: 8
					anchors.verticalCenter: parent.verticalCenter
					text: tr.Localize(account.isControlEnabled ? "TurnOff" : "TurnOn")
					minWidth: 90
					onClicked: account.isControlEnabled ? context.DisableParentalControl(account.id) : context.EnableParentalControl(account.id)
					onActiveFocusChanged: if (activeFocus) accounts.focusColumnIdChanged(columnId);
				}

				property int currentFocusColumnId: accounts.currentFocusColumnId
				onCurrentFocusColumnIdChanged: updateItemFocus()
				onVisibleChanged: updateItemFocus()
				onEnabledChanged: updateItemFocus()
				Component.onCompleted: updateItemFocus()

				function updateItemFocus()
				{
					if (!updateItemFocusing(settingsBtn))
						updateItemFocusing(btnOnOff);
				}

				function updateItemFocusing(item)
				{
					if (item.columnId != currentFocusColumnId)
						return false;

                    if (!item.focus && item.visible && item.enabled)
						item.focus = true;
					return true;
				}

                Rectangle
                {
                    anchors.bottom: parent.bottom
                    width: parent.width
                    height: 1
                    color: "#e7e7e7"
                }
			}
		}
	}
}
