import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/Margins.js" as Margins

Item
{
	id: enterPassword
	objectName: "enterPassword"
	Localizer { id:tr; scope:"ParentalControl" }
	width:  parent.width
	height: parent.height
	
	property variant context: MainWindow.GetSubViewModel("ParentalControl")
	property string error: ""
	property variant commonFontStyles: Fonts.Common{}
	
	function setActiveFocus()
	{
		testPassword.setActiveFocus();
	}
    
	Component.onCompleted:
	{
		context.PasswordEnter.VerifyPassword()
	}

	Component.onDestruction:
	{
		if (context && !context.PasswordEnter.IsRememberPassword)
			context.PasswordEnter.ResetPassword();
	}
	
	Widgets.StandardCaptionText
	{
		id: header
        y: 120
		anchors.horizontalCenter: parent.horizontalCenter
		text: tr.Localize("EnterPassword")
	}
	
	Text
	{
		id: description
		anchors.top: header.bottom
        anchors.topMargin: Margins.verticalCaptionToCommonText
		anchors.horizontalCenter: parent.horizontalCenter
		horizontalAlignment: Text.AlignHCenter
        width:  parent.width - 300
		text: tr.Localize("PasswordEnterDescription")
		font: commonFontStyles.standardCommonTextFont
		color: "black"
		wrapMode: Text.Wrap
        lineHeight: Margins.commonTextLineHeight
	}	

	Widgets.EditBox
	{
		id: testPassword
		objectName: "EnterPasswordEditbox"
		anchors.top: description.bottom
        anchors.topMargin: Margins.verticalCommonTextToWidget
		anchors.horizontalCenter: parent.horizontalCenter
		width:  180
        height: 25
		isPassword: true
		fontBold: true
		text: context.PasswordEnter.Password
	}
		
	Binding {target: context.PasswordEnter; property: "Password"; value: testPassword.text }

	Widgets.GrayButton
	{
		id: login
		setAsDefaultButton: true
		objectName: "LoginButton"
		anchors.top: testPassword.bottom
        anchors.topMargin: 18
		anchors.horizontalCenter: parent.horizontalCenter
		text: tr.Localize("Login")
		onClicked:
		{
			error = context.PasswordEnter.VerifyPassword() ? "" : tr.Localize("PasswordIncorrect")

			if (!context.PasswordEnter.IsRememberPassword)
				context.PasswordEnter.ResetPassword();
		}
        minWidth: 100
	}

	Text
	{
		anchors.top: login.bottom
		anchors.topMargin: 20
		anchors.horizontalCenter: parent.horizontalCenter
		text: error
		font: commonFontStyles.standardCommonTextFont
		color: "red"
	}
	
	Widgets.CheckBox
	{
		id: rememberCheckBox
		objectName: "rememberCheckBox"
		anchors.bottom: parent.bottom
        anchors.bottomMargin: 35
		anchors.horizontalCenter: parent.horizontalCenter
		text: tr.Localize("RememberPassword")
        textVerticalMargin: 1
        horizontalMargin: 5
		property: "IsRememberPassword"
		target: context.PasswordEnter
	}
}
