import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../main_window" as MainFrame
import "../common/HelpMapper.js" as HelpMapper

MainFrame.InnerContent
{
	Localizer { id:tr; scope:"MainWindow" }
    caption: tr.scope === undefined ? "" : tr.Localize("ParentalControl")
	property variant context: MainWindow.GetSubViewModel("ParentalControl")
    property int helpId

	objectName: "parentalControlPage"
	id: parentalControlPage
	viewArea: Component
	{
		Item
		{			
			anchors.fill: parent
			objectName: "parentalControl"
			property variant context: MainWindow.GetSubViewModel("ParentalControl")
			
			Component.onCompleted:
			{
				context.PasswordSet.IsPasswordSkiped = false
			}
			
			ApplyExistPassword
			{
				visible: context.PasswordEnter.IsPasswordSpecified && 
				!context.PasswordSet.ShouldAskPasswordParentalControl &&
				!context.PasswordSet.IsPasswordSkiped

                onVisibleChanged:
                {
                    if(visible)
                        helpId = HelpMapper.ParentalControlPasswordInputHelpId
                }
			}
			
			EnterPassword
			{
				id: enterPassword
				visible:	context.PasswordEnter.IsPasswordSpecified &&
							context.PasswordSet.ShouldAskPasswordParentalControl &&
							context.PasswordEnter.IsInvalidPassword
				Connections
				{
					target: parentalControlPage
					onActivationCompleted: enterPassword.onActivated()
				}
				onVisibleChanged: onActivated();

				function onActivated()
				{
					if (visible && enabled)
                    {
						setActiveFocus();
                        helpId = HelpMapper.ParentalControlPasswordInputHelpId
                    }
				}
			}
			
			SetupPassword
			{
				id: setPassword
				visible: !context.PasswordEnter.IsPasswordSpecified && !context.PasswordSet.IsPasswordSkiped
				Connections
				{
					target: parentalControlPage
					onActivationCompleted: setPassword.onActivated()
				}
				onVisibleChanged: if (visible) parentalControlPage.windowChanged()

				function onActivated()
				{
					if (visible && enabled)
                    {
                        helpId = HelpMapper.ParentalControlPasswordInputHelpId
						setActiveFocus();
                    }
				}
			}
			
			AccountList
			{
				visible: (context.PasswordEnter.IsPasswordSpecified && !context.PasswordEnter.IsInvalidPassword) 
							|| context.PasswordSet.IsPasswordSkiped
                onVisibleChanged:
                {
                    if (visible)
                    {
                        helpId = HelpMapper.ParentalControlAccountListHelpId
                        parentalControlPage.windowChanged()
                    }
                }
			}
		}
	}
}
