import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/HelpMapper.js" as HelpMapper

ActivationBasePage
{
	Localizer { id:tr; scope:"LicenseManager" }
	headerString:		context.IsOfflineActivation ? tr.Localize("KeyForOtherProductOfflinePageHeader") : tr.Localize("KeyForOtherProductPageHeader")

	objectName: "KeyForOtherProductPageHeader"

	function getHelpId()
	{
		return ProductTypeHelper.isKIS() ? HelpMapper.ActivationPageOtherProductHelpIdKIS : HelpMapper.ActivationPageOtherProductHelpIdKAV;
	}

	Component
	{
		id: infoBlockOfflineActivation
		
		Widgets.StaticLabel
		{
			objectName: "keyForOtherProductPageInfoBlockOfflineActivation"
			anchors.left: parent.left
			anchors.right: parent.right
			
			caption:		tr.Localize("KeyForOtherProductPageInfoBlockOfflineActivation")
			value:			context.ProductName == "" ? "" : tr.Localize("ProductName_" + context.ProductName)
			captionFont:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
			valueFont:		activationWizard.fontStyles.masterOfActivationButtonsNormalText
		}
	}
	
	Component
	{
		id: infoBlockGeneral
		
		Column
		{
			anchors.left: parent.left
			anchors.right: parent.right			
			
			spacing: 5
			
			Widgets.StaticLabel
			{
				objectName: "keyForOtherProductPageInfoBlockActivationCode"
				caption:		tr.Localize("KeyForOtherProductPageInfoBlockActivationCode")
				value:			context.ActivationCode
				captionFont:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
				valueFont:		activationWizard.fontStyles.masterOfActivationButtonsNormalText
				anchors.left: parent.left
			}
			Widgets.StaticLabel
			{
				objectName: "keyForOtherProductPageInfoBlockProductName"
				caption:		tr.Localize("KeyForOtherProductPageInfoBlockProductName")
				value:			context.ProductName == "" ? "" : tr.Localize("ProductName_" + context.ProductName)
				captionFont:	activationWizard.fontStyles.masterOfActivationButtonsNormalText
				valueFont:		activationWizard.fontStyles.masterOfActivationButtonsNormalText
				anchors.left: parent.left
			}		
		}
	}	

	Loader
	{
		id: infoBlock
		
		anchors.left: parent.left
		anchors.right: parent.right	
		
		sourceComponent: context.IsOfflineActivation ? infoBlockOfflineActivation : infoBlockGeneral
	}
	
	Text
	{
		id: questionText
		objectName: "questionText"

		anchors.top : infoBlock.bottom
		anchors.topMargin: 30
		anchors.left: parent.left
		
		width: parent.width
		
		font:			activationWizard.fontStyles.stateTextForWaitingActivation
		wrapMode:		Text.Wrap
		horizontalAlignment: Text.AlignLeft
		text:			tr.Localize("KeyForOtherProductPageChoiceText", {"ProductName":context === undefined ? "" : ProductTypeHelper.getProductName(tr, context)})
	}		

	Widgets.RadioGroup {id: radioGroupSelectionForChangeProductType}
	Widgets.RadioButton
	{
		id:						selectionForActivateWithNewCode
		objectName: "selectionForActivateWithNewCode"
		
		anchors.top:			questionText.bottom
		anchors.topMargin:		18
		
		anchors.left: parent.left
		anchors.right: parent.right
		
		text:					tr.Localize("KeyForOtherProductPageChoice1")
		color: 					"transparent"
		group:					radioGroupSelectionForChangeProductType
		horizontalMargin:		7
		textfont:				activationWizard.fontStyles.checkBoxTextRegistrationPage
		checked:				true
		wrapMode: Text.WordWrap
		
		onCheckedChanged:
		{
			if (checked)
				context.UserChoice = "UserChoice_ActivateWithNewCode";
		}
	}

	Widgets.RadioButton
	{
		id:						selectionForChangeProductType
		objectName: "selectionForChangeProductType"
		
		anchors.top:			selectionForActivateWithNewCode.bottom
		anchors.topMargin:		10		
		
		anchors.left: parent.left
		anchors.right: parent.right		
		function getChoiceText()
		{
			var key = context.IsOfflineActivation ? "KeyForOtherProductPageOfflineChoice2" : "KeyForOtherProductPageChoice2";
			var productName = context.ProductName == "" ? "" : tr.Localize("ProductName_" + context.ProductName);
			return tr.Localize(key, {"ActivationCodeProduct" : productName});
		}
		text:					getChoiceText()
		color: 					"transparent"
		group:					radioGroupSelectionForChangeProductType
		horizontalMargin:		7
		textfont:				activationWizard.fontStyles.checkBoxTextRegistrationPage
		wrapMode: Text.WordWrap
		
		onCheckedChanged:
		{
			if (checked)
				context.UserChoice = "UserChoice_Migrate";
		}			
	}
	
	Widgets.RadioButton
	{
		id:						selectionForSetCodeToReserve
		objectName: "selectionForSetCodeToReserve"
		
		anchors.top:			selectionForChangeProductType.bottom
		anchors.topMargin:		12
		
		anchors.left: parent.left
		anchors.right: parent.right	
				
		text:					tr.Localize("KeyForOtherProductPageChoice3")
		color: 					"transparent"
		group:					radioGroupSelectionForChangeProductType
		horizontalMargin:		7
		textfont:				activationWizard.fontStyles.checkBoxTextRegistrationPage
		visible:				context.ActivationPageOtherProductDueActivation.IsPossibleToReserveCode
		wrapMode: Text.WordWrap
		onCheckedChanged:
		{
			if (checked)
				context.UserChoice = "UserChoice_Reserve";
		}
	}
}

