import QtQuick 1.1
import "../Common.js" as Common
import "../Stat.js" as Stat

Item
{
	signal clicked()
	signal entered
	signal exited
	signal pressed
	signal pressAndHold
	signal released
	id: baseButton
	objectName: "BaseButton"
	property bool setFocusOnPressed: tabOrder ? true : false
	property bool focusRectEnabled: true
	property alias focusRectTarget: focusRectangle.target

	function click()
	{
		if (!baseButton.activeFocus && baseButton.setFocusOnPressed)
			baseButton.forceActiveFocus();

        Stat.onButtonClick(Common.buildDelegatelessPath(baseButton));
		baseButton.clicked();
	}

	FocusRect
	{
		id: focusRectangle
		target: focusRectEnabled ? baseButton : undefined
		anchors.fill: parent
		anchors.topMargin: 3
		anchors.bottomMargin: 4
		anchors.rightMargin: 4
		anchors.leftMargin: 3
	}

	property int tabOrder: 1
	Keys.onSpacePressed: click();
	Keys.onReturnPressed: click();
	Keys.onEnterPressed: click();

	function selectValue(disabled, normal, hover, pressed)
	{
		if (!enabled)
			return disabled ? disabled: normal;
		if (state == "pressed" && pressed)
			return pressed;
		if ((state == "pressed" || state == "hover") && hover)
			return hover;
		return normal;
	}

	states
	{
		State
		{
			name: "normal"
			when: !mouseArea.containsMouse
		}
		State
		{
			name: "hover"
			when: mouseArea.containsMouse && mouseArea.pressedButtons != Qt.LeftButton
		}
		State
		{
			name: "pressed";
			when: mouseArea.containsMouse && mouseArea.pressedButtons == Qt.LeftButton;
		}
	}

	MouseArea
	{
		id:				mouseArea
		anchors.fill:	parent
		hoverEnabled:	parent.enabled
		Clickable {}
		onClicked: click();
		onEntered: baseButton.entered();
		onExited: baseButton.exited();
		onPressed: baseButton.pressed();
		onPressAndHold: baseButton.pressAndHold();
		onReleased: baseButton.released();
	}

	property variant defaultButtonManager: initDefaultButtonManager()
	function initDefaultButtonManager()
	{
		var current = baseButton;
		while (current = current.parent)
			if (current.defaultButtonManager)
				return current.defaultButtonManager;
	}
}
