import QtQuick 1.1
import "spin_details" as Details

Rectangle
{
	id: widget
	property variant target
	property string property
	property variant minValue
	property variant maxValue
	property variant behaviour: Details.IntBehaviour {}

	Binding { target: behaviour; property: "target"; value: widget.target }
	Binding { target: behaviour; property: "property"; value: widget.property }
	Binding { target: behaviour; property: "minValue"; value: widget.minValue; when: widget.minValue !== undefined }
	Binding { target: behaviour; property: "maxValue"; value: widget.maxValue; when: widget.maxValue !== undefined }

	objectName: "Spin"
    implicitHeight: 21
    implicitWidth: 18
	property color frameColor: enabled ? "black" : "lightgray"
	radius: 3
	property int tabOrder: 1

    Image
    {
        anchors.fill: parent

        source: "../images/widgets/spin_background.png"
        mirror: Window.Mirror
    }

	Column
	{
        objectName: "Column"
        anchors.top: parent.top
        anchors.topMargin: 2
        anchors.right: parent.right
        anchors.rightMargin: 2
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 2
        spacing: 1

		Details.Button
		{
			objectName: "Up"
            backgroundImage: "../images/widgets/spin_up_button.png"
            disabledImage: "../images/widgets/spin_up_button_disabled.png"
            width: 15
            height: 8
			spin: widget
			func: "increment"
        }

        Details.Button
		{
			objectName: "Down"
            backgroundImage: "../images/widgets/spin_down_button.png"
            disabledImage: "../images/widgets/spin_down_button_disabled.png"
            width: 15
            height: 8
			spin: widget
			func: "decrement"
		}
	}
	Keys.onUpPressed: processKeyPressed(event, "increment");
	Keys.onDownPressed: processKeyPressed(event, "decrement");
	property bool keyRepeat: false
	function processKeyPressed(event, func)
	{
		console.log();
		if (!event.isAutoRepeat)
		{
			widget[func](1);
		}
		else if (!keyRepeat)
		{
			keyRepeat = true;
			widget.start(func);
		}
	}
	Keys.onReleased:
	{
		if (event.isAutoRepeat || !keyRepeat)
			return;
		widget.stop();
		keyRepeat = false;
	}

	function increment(count)
	{
		behaviour.increment(count);
	}
	function decrement(count)
	{
		behaviour.decrement(count);
	}
	function start(func)
	{
		behaviour.start(func);
	}
	function stop(func)
	{
		behaviour.stop(func);
	}
}
