import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/Common.js" as Common
import "../common/fonts" as Fonts
import "../common/EnumHelper.js" as EnumHelper

Item
{
	id: dashboard
	objectName: "Dashboard";
	signal problemListButtonPressed
	property int tabOrder: 1

	property variant fontStyles: Fonts.Fonts{}
	property variant context: MainWindow.dashboard
	
	Localizer { id:tr; scope:"Dashboard" }
	
	function getSubscriptionRemainingDays()
	{
        if(context.ShouldShowRemainingSubscriptionDays)
        {
            if(context.ActiveLicenseRemainingDays != 0)
               return tr.Localize("SubscriptionActive", {"LicenseState_RemainingDaysCount": context.LicenseRemainingDaysCount});
            else
               return tr.Localize("ExpiredToday");
        }
		return tr.Localize("SubscriptionActiveExpirationDateUnknown");
	}
	
	function getLicenseExpiredEx()
	{
		if(context.ActiveLicenseRemainingDays != 0)
			return tr.Localize("LicenseRemainDays", {"LicenseState_RemainingDaysCount": context.LicenseRemainingDaysCount});
		else
			return tr.Localize("ExpiredToday");
	}
	
	function getButtonTypeName()
	{
		var customTitle = context.BuyRenewCustomTitle;
		if(customTitle != "")
			return customTitle;
		if(EnumHelper.getKey(context, "BuyRenewType") == "Buy")
			return tr.Localize("BuyNow");
		if(EnumHelper.getKey(context, "BuyRenewType") == "Renew")
			return tr.Localize("Renew");
		return "";
	}
	
	function getRecommendationsStateDescription()
	{
		if(EnumHelper.getKey(context, "RecomendationStatus") == "EnableAutomaticUpdates")
			return tr.Localize("EnableAutomaticUpdates");
		if(EnumHelper.getKey(context, "RecomendationStatus") == "TrainAntiSpam")
			return tr.Localize("TrainAntiSpam");
		return "";
	}

	Widgets.BaseButton
	{
	    id: dashboardButton
	    objectName: "DashboardButton";
	    anchors.fill:parent
        anchors.topMargin: 14 // dashboard picture shadow margin
        anchors.bottomMargin: 105
        anchors.leftMargin: 19
        anchors.rightMargin: 165
	    onClicked: dashboard.problemListButtonPressed()

        Image
	    {
	        id: image;
            anchors.fill: parent
            source: dashboardButton.selectValue("", "../common/images/main_window/contentarea_mainscreen.png")
        }

		function getProductColorText(objects, propertyNames)
		{
			return EnumHelper.convert(objects, propertyNames, {
                        "Unknown":"#ffffff",
                        "Info":"#006955",
                        "Warning":"#fab210",
                        "Critical":"#ac000a"});
		}

	    function getProductStateImage(object, propertyName)
	    {
	        return EnumHelper.convert(object, propertyName, {
	                        "Unknown":"",
	                        "Info":"../common/images/main_window/computer_ok.png",
	                        "Warning":"../common/images/main_window/computer_problem.png",
                            "Critical":"../common/images/main_window/computer_risk.png"});
	    }

	    Image
	    {
	        id: statusImage
            anchors.left:parent.left
            anchors.leftMargin: 15
            anchors.top: statusesWrapper.top
            Widgets.DPIScaler { id: dpiScaler }
	        Widgets.DPIScaler{changeSize:true; changeX:true}
            source: dashboardButton.getProductStateImage(context, "ProductState")
            smooth: true
	    }        

        Item
        {
            id: statusesWrapper
            height: childrenRect.height
            width: childrenRect.width
            anchors.left : statusImage.right
            anchors.leftMargin : 10
            anchors.right: parent.right
            anchors.rightMargin: 0
            anchors.top: parent.top
            anchors.topMargin: 20

            Text
            {
                id: stateText
                objectName: "ProductState";
                anchors.left: parent.left
                anchors.right: parent.right
                font: fontStyles.dashboardProductStateFont
				color: dashboardButton.getProductColorText(context, "ProductState")
                function prepareProductStateText()
                {
                    if(context.hasLicenseNotification && context.shouldOverrideProductState)
					{
						if (context.licenseNotificationProductState != "")
	                        return context.licenseNotificationProductState;
					}
                    return tr.Localize(context.ProductStateDescription);
                }

				Connections
				{
					target: context;
					onProtectionStateDescriptionChanged: stateText.text = stateText.prepareProductStateText();
				}

                text: prepareProductStateText();
                elide: Text.ElideRight
            }

            Column
            {
                id: statuses
                anchors.left: stateText.left; anchors.leftMargin: 1
                anchors.right: parent.right; anchors.rightMargin: 20
                anchors.top: stateText.bottom
                anchors.topMargin: 11
                spacing: 1
                property real infoRowHeight: (statusImage.height * 0.7) / 5

                InfoRow // Active threats
                {
                    stateId : "ThreatsState"
                    itemId : tr.Localize("ThreatsState")
                    value : tr.Localize(context.ThreatsStateDescription)
                    height : statuses.infoRowHeight
                }

                InfoRow // Protection components
                {
                    stateId : "ProtectionState"
                    itemId : tr.Localize("ProtectionState")
                    value : tr.Localize(context.ProtectionStateDescription)
                    height : statuses.infoRowHeight
                }

                InfoRow // Bases
                {
                    stateId : "BasesState"
                    itemId : tr.Localize("BasesState")
                    function getBasesDescription()
                    {
                        if(EnumHelper.getKey(context, "UpdaterStatus") != "Idle")
                        {
                            return	tr.Localize(context.BasesStateDescription) + 
								(EnumHelper.getKey(context, "UpdaterStatus") == "RollbackRunning"
                                    ? tr.Localize("BasesRollbacking", {"BasesState_ProcessPercentCompleted" : context.BasesProcessPercentCompleted})
                                    : tr.Localize("BasesUpdating", {"BasesState_ProcessPercentCompleted" : context.BasesProcessPercentCompleted}));
                        }
                        return tr.Localize(context.BasesStateDescription);
                    }

                    value : getBasesDescription()
                    height : statuses.infoRowHeight
                }

                InfoRow // subscription
                {
					function hasValueText()
					{
						return context.LicenseStateDescription || context.hasLicenseNotification;
					}

                    function prepareSubscriptionText()
                    {
                        if(context.hasLicenseNotification)
                        {
                            var text = context.licenseNotificationLicenseState;
                            if(text != "")
                                return text;
                        }

                        return tr.Localize(context.LicenseStateDescription, {
                            "LicenseExpiredEx" : dashboard.getLicenseExpiredEx(),
                            "SubscriptionRemainingDays" : dashboard.getSubscriptionRemainingDays(),
                            "LicenseState_RemainingDaysCount": context.LicenseRemainingDaysCount
                            });
                    }
                    visible: context.IsSubscriptionLicense
                    itemId : tr.Localize("SubscriptionState")
                    stateId : "LicenseState"
					value : hasValueText() ? prepareSubscriptionText() : "";
                    height : statuses.infoRowHeight
                }

                InfoRow // Licenses
                {
					function hasValueText()
					{
						return context.LicenseStateDescription || context.hasLicenseNotification;
					}
                    function prepareLicenseText()
                    {
                        if(context.hasLicenseNotification)
                        {
                            var text = context.licenseNotificationLicenseState;
                            if(text != "")
                                return text;
                        }
                        return tr.Localize(context.LicenseStateDescription, {
                            "LicenseExpiredEx" : dashboard.getLicenseExpiredEx(),
                            "LicenseState_RemainingDaysCount": context.LicenseRemainingDaysCount
                            });
                    }
                    visible: !context.IsSubscriptionLicense
                    itemId : tr.Localize("LicenseState")
                    stateId : "LicenseState"
                    value : hasValueText() ? prepareLicenseText() : "";
                    height : statuses.infoRowHeight
                }

                InfoRow // Recommendations
                {
                    stateId : "RecommendationsState"
                    itemId : tr.Localize("RecommendationsState")
                    value : dashboard.getRecommendationsStateDescription()
                    visible: context.HasRecommendations;
                    height : statuses.infoRowHeight
                }
            }
        }
	}
}
