import QtQuick 1.1
import "../common/widgets" as Widgets

Item
{
    id: featureBox
    signal activate(string panelName)
    objectName: "FeatureBox"
    property Item currentView: list
    property Item smallView:   list
    property Item hiddenView:  table
	property int tabOrder: 1
    width:  parent.width
    height: list.height

    property bool canUp: currentView == list && !animationRunning
    property bool canDown: currentView == table && !animationRunning
    property bool animationRunning: animation.running
	property bool toolViewOwnsFocus: false
    property bool hideTongue: false

	Connections
	{
		target: animation
		onRunningChanged: featureBox.animationRunning = animation.running;
	}
    function up()
    {
    	doSwitch();
        doAnimation(true, true);
    }

    function down()
    {
    	doSwitch();
        doAnimation(false, false);
    }

    SequentialAnimation
    {
        id: animation
        ScriptAction
        {
            id: preScript
            property bool enabled: true
            script:
            {
            	if (enabled)
                    setVisibility();
            }
        }
        NumberAnimation
        {
            id: animation1
        }
        NumberAnimation
        {
            id: animation2
        }
        ScriptAction
        {
            id: postScript
            property bool enabled: true
            script:
            {
                if (enabled)
                    setVisibility();
            }
        }
    }

    function doSwitch()
    {
                var temp = currentView
        currentView = hiddenView
        hiddenView = temp
    }

    function empty()
    {
    }

    function setVisibility()
    {
        currentView.visible = true
        hiddenView.visible = false
    }

    function doAnimation(orderInverted, setVisibilityAtStart)
    {
        animation.running = false

        var heightAnimation = orderInverted ? animation2 : animation1
        var widthAnimation = orderInverted ? animation1 : animation2

        preScript.enabled = setVisibilityAtStart
        postScript.enabled = !setVisibilityAtStart

        heightAnimation.target = featureBox
        heightAnimation.property = "height"
        heightAnimation.from = height
        heightAnimation.to = currentView.height
        heightAnimation.duration = Math.abs(heightAnimation.from - heightAnimation.to) / 1.2
        widthAnimation.target = toolViews
        widthAnimation.property = "width"
        widthAnimation.from = toolViews.width
        widthAnimation.to = toolViews.currentWidth()
        widthAnimation.duration = Math.abs(widthAnimation.from - widthAnimation.to) / 1
        animation.running = true
    }

    Item
    {
        objectName: "clipper"
        clip: true
        anchors
        {
            fill: parent
            topMargin: -100 // don't clip at top - here is up button
            bottomMargin: 37 /* footer and separator */ - 150 /* bottom image */
        }

        Item
        {
            objectName: "corrector"
            anchors
            {
                fill: parent
                topMargin: 100 // correct y coordinate
            }

            Item
            {
                id: toolViewsWrapper
                objectName: "ToolViewsWrapper"
                height: parent.height
                width: parent.width
                anchors.left: parent.left
                clip: true

                Item
            {
                id: toolViews
                objectName: "toolViews"
                property real fullWidth: parent.width
                property real widthWithLeftRight: fullWidth - 10 * 2
                function currentWidth()
                {
                    return currentView.canLeft || currentView.canRight ? widthWithLeftRight : fullWidth;
                }
                anchors.horizontalCenter: parent.horizontalCenter
               ToolList
                {
                    id: list
                   visible: false	
                    objectName: "toolPanel"
                    anchors.left:  parent.left
                    anchors.right: parent.right
                    onActivate: featureBox.activate(panelName)
                }

                ToolPanel
                {
                    id: table
                    objectName: "toolPanel"
                    width: parent.width

                    onActivate: featureBox.activate(panelName)
                }
                Component.onCompleted : width = currentWidth()
            }
            }

Widgets.Button
            {
                objectName: "right"
                property int tabOrder: 304
                iconImage: ""
                anchors.top: parent.top
                anchors.bottom: parent.bottom
                anchors.left: toolViews.right
                anchors.leftMargin: -2
                enabled: !animation.running && currentView.canRight
                onClicked: currentView.doRight()
            }
        }
    }
}
