import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../dashboard" as Dashboard
import "../common/ViewManager.js" as ViewManagerForBackView
import "../common/EnumHelper.js" as EnumHelper
import "../common/border" as Border
import "../common/fonts" as Fonts
import "../common/HelpMapper.js" as HelpMapper
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/Stat.js" as Stat

Widgets.FlipableY
{
	id: flipPanel

	property variant defaultButtonManager: defaultButtonManagerId

	Widgets.DefaultButtonManager{id: defaultButtonManagerId}
	Keys.forwardTo: defaultButtonManagerId
	focus: true

	objectName: "TopFlipPanel"
    property int panelWidth: 750
	property int panelHeight: 505
	width: childrenRect.width
	height: childrenRect.height

	front: mainViewBordered
	back: backViewBordered

	property bool firstShow: true
	animated: !firstShow
	
	Localizer { id:tr; scope:"MainWindow" }

	LayoutMirroring.enabled: Window.Mirror
	LayoutMirroring.childrenInherit: true

	function isPanel(page)
	{
		var i;
		var tool;
		for (i = 0; i < MainWindow.toolsList.length; ++i)
		{
			tool = MainWindow.toolsList[i];
			if (tool.ComponentType == page && !Qt.isQtObject(tool.Action))
				return true;
		}
		return false;
	}

	function showPage(page)
	{
		var separatorPosition = page.search(":");
		if (separatorPosition == -1) separatorPosition = page.length;
		if (!separatorPosition)
			return;
		var currentPage = page.slice(0, separatorPosition);
		var page = page.slice(separatorPosition + 1);
		var panelName;

        var mapOfWindowParams = {
            "ActivationWizard":		{path: "../activation/ActivationWizard.qml", isOnBackSide: true},
            "MigrationWizard":		{path: "../migration/MigrationWizard.qml", isOnBackSide: true},
            "Updater":				{panel: "panelUpdater", isOnBackSide: false},
            "ProblemList":			{panel: "panelProblemList", isOnBackSide: false},
            "Scan":					{panel: "panelScan", isOnBackSide: false},
            "Online":				{panel: "panelOnline", isOnBackSide: false},
            "NewsList":				{panel: "panelNewsList", isOnBackSide: false},
            "NewsItem":				{panel: "panelNewsItem", isOnBackSide: false},
            "Search":				{panel: "panelSearch", isOnBackSide: false},
            "Tools":				{panel: "panelTools", isOnBackSide: false},
            "Upgrade":				{panel: "panelUpgrade", isOnBackSide: false},
            "LicenseManager":		{panel: "panelLicenseManager", isOnBackSide: false},
            "SafeBanking":          {panel: "panelSafeBanking", isOnBackSide: false, productType: "kis"},
			"UcpWizard":			{panel: "panelUcpWizard", isOnBackSide: false}
        };

		var params = mapOfWindowParams[currentPage];
        if (!params || (!params.path && !params.panel) || (params.productType && params.productType !== ProductTypeHelper.productTypeToString(MainWindow)))
		{
			if (isPanel(currentPage))
			{
				panelName = "panel" + currentPage;
				params = {panel: panelName, isOnBackSide: false};
			}
			else
			{
				console.log("windowPage for '" + currentPage + "' has not been found");
				return;
			}
		}
		firstShow = firstShow && currentPage == "ActivationWizard"
		var newPage = undefined;
        if (params.isOnBackSide)
		{
			newPage = backView.showPage(params);
		}
		else
		{
			mainView.showPage(params);
			var currentPage = mainView.getInnerPanel().getCurrent();
			if (flipPanel.isFlipped())
				backView.closePage();
			if(currentPage && currentPage.showPage)
				currentPage.showPage(page);
		}
		if (page && newPage && (typeof newPage.showPage == "function"))
			newPage.showPage(page);
		firstShow = false;
	}

	Border.BorderedContent
	{
		id: backViewBordered
		objectName: "backViewBordered"
		content: backView
		enabled: flipPanel.isFlipped()
    }

	Widgets.HotKeyScope
	{
		id: backViewScope
		width: panelWidth
		height: panelHeight
		parent: backViewBordered
		CustomLoader
		{
			id: backView
			objectName: "backView"
			width: panelWidth
			height: panelHeight

			function getHelpId()
			{
				return item.getHelpId();
			}

			function showPage(params)
			{
				if (file == params.path)
					return;
				viewManager().goTop();
				file = params.path;
				viewManager().goTop();
				viewManager().show(eval(backView));
				item.duration = 0;
				return backView;
			}
			function closePage()
			{
				backView.file = "";
				flipPanel.flipBack();
			}
			Connections
			{
				target: backView.item
				onClose: Window.Close()
				onCancel: backView.closePage()
				onShowHelp: flipPanel.showHelp()
			}
			Connections
			{
				target: flipPanel
				onAnimationFinished:
				{
					flipPanel.back.focus = isFlipped() ? true : false;
					flipPanel.front.focus = isFlipped() ? false : true;
					if (!flipPanel.isFlipped())
						backView.viewManager().doBack();
					else
					{
						if (backView.item.animationCompleted)
							backView.item.animationCompleted();
					}
				}
			}
			function viewManager() {return ViewManagerForBackView;}

			onStatusChanged:
			{
				switch (status)
				{
					case Loader.Null:
					{
						if (!file)
							flipPanel.flipBack();
						break;
					}
					case Loader.Error:
					{
						source = "";
						closePage();
						break;
					}
				}
			}
			onLoaded:
			{
				flipPanel.flip();
			}
		}
	}

	Border.BorderedContent {
		id: mainViewBordered
		content: mainView
		enabled: !flipPanel.isFlipped()
    }

	Widgets.HotKeyScope
	{
		id: mainView
		parent: mainViewBordered
		width: panelWidth
		height: panelHeight
		objectName: "MainView"
        property int helpId: HelpMapper.MainWindowHelpId

		function showPage(params)
		{
			if (params.panel)
				innersView.show(params.panel);
		}

		function getInnerPanel()
		{
			return innersView.getCurrent();
		}

		function getHelpId()
		{
			if (innersView.enabled)
				return innersView.getHelpId();
			return helpId;
		}

		Item
		{
			id: backLayer
			objectName: "BackLayer"
			anchors.fill: parent
            enabled: innersView.opacity == 0

			Connections
			{
				target: innersView
				onInnersViewShow: backLayer.enabled = false;
				onInnersViewHide:
				{
					backLayer.enabled = true;
					// TODO: need to restore focus item
				}
				onShowHelp: flipPanel.showHelp()

            }

            BorderImage
        {
            id: mainBackground
                anchors.fill: parent
                anchors.bottomMargin: 0
                border { left: 0; top: 0; right: 0; bottom: 0 }
                source: "../common/images/main_window/bg_small.png"

                Rectangle
                {
                    }
            }

            Dashboard.Dashboard
            {
                id: dashboard
                tabOrder: 1
                objectName: "dashboard"
                anchors.top: parent.top
                anchors.topMargin: 77 * dpiScaler.factor /* from guideline */
                height: 297 * dpiScaler.factor
                anchors.left   : parent.left
                anchors.right  : parent.right
                property bool featureBoxCoveredMe: featureBox.canDown
                visible: !featureBoxCoveredMe

                function onNavigateTo()
                {
                    Stat.onNavigateTo(objectName);
                    MainWindow.dashboard.IPM.reportShowStatistics();
                }

                Connections
                {
                    target: MainWindow.dashboard.IPM;
                    onContentChanged: MainWindow.dashboard.IPM.reportShowStatistics();
                }

                Component.onCompleted:
                {
                    onNavigateTo()
                }
                onProblemListButtonPressed: innersView.show("panelProblemList")
            }

			FeatureBox
			{
				id: featureBox
				property int tabOrder: 3
                objectName: "featureBox"
                anchors.bottom: parent.bottom
				anchors.bottomMargin: 47
				anchors.left:   parent.left
				anchors.right:  parent.right
                onActivate:	 innersView.show(panelName)
                hideTongue: innersView.opacity === 1
            }

            Item
            {
                id: footerSeparator
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.bottomMargin: 35
                height: childrenRect.height
                width: parent.width - 2

                Rectangle
                {
                    }
            }

            MainFooter
            {
                id: mainFooter
                tabOrder: 4
                objectName: "mainFooter"
                anchors.left:   parent.left
                anchors.right:  parent.right
                anchors.bottom: parent.bottom
                anchors.top: footerSeparator.bottom
                textColor: "#ffffff"
                textcolorHovered: "#73cab4"
				textcolorPressed: "#004b41"
                focusSource: ""
            }
            Widgets.Button
            {
                objectName: "logo"
                iconImage: "../images/main_window/logo.png"
                anchors.top: parent.top
                anchors.topMargin: 30
                anchors.left: parent.left
                anchors.leftMargin: 30
				onClicked: MainWindow.startPage.ShowProductInfo()
            }

			Image
            {
                function getProductTypeImage(context, productType)
                {
                    return EnumHelper.convert(context, productType, {
                        "KasperskyInternetSecurity" : "../common/images/about/about_title_kis.png",
                        "KasperskyAntiVirus" : "../common/images/about/about_title_kav.png",
                        "Unknown": ""});
                }
			x: 250
			y: 30
                source: getProductTypeImage(MainWindow, "productType")
            }

            Widgets.Button
            {
                objectName: "Settings"

				x: 603                
				y: 91
				width: 128
				height: 80                                
                text: tr.Localize("Settings")
                backgroundImage: "../images/main_window/featurebox/icons_11.png"
                onClicked: MainWindow.InvokeSkinAction("window(\"QMLSettings\")")
                textcolor:			"white"
				textcolorPressed:	"#999999"
				textfont.family: "FranklinGothicMediumTT"
				textfont.pointSize: 10
				textWidth: 150
                horizontalMargin: 12
                textVerticalOffset: 30
            }

			Widgets.Button
            {
                objectName: "Reports"

				x: 603                
				y: 189
				width: 128
				height: 80                                
                text: tr.Localize("Reports")
                backgroundImage: "../images/main_window/featurebox/icons_12.png"
                onClicked: MainWindow.InvokeSkinAction("window(\"StatisticsReport\")")
                textcolor:			"white"
				textcolorPressed:	"#999999"
				textfont.family: "FranklinGothicMediumTT"
				textfont.pointSize: 10
				textWidth: 150
                horizontalMargin: 12
                textVerticalOffset: 30
            }

			Widgets.Button
            {
                objectName: "CloudProtection"

				x: 603                
				y: 388
				width: 128
				height: 80                                
                Localizer { id:trOnline; scope:"Online" }
				text:				trOnline.Localize("CloudProtectionBig")
                backgroundImage: "../images/main_window/featurebox/icons_13.png"
                onClicked: MainWindow.InvokeSkinAction("window(\"QMLMainWindow:Online\")")
                textcolor:			"white"
				textcolorPressed:	"#999999"
				textfont.family: "FranklinGothicMediumTT"
				textfont.pointSize: 10
				textWidth: 150
                horizontalMargin: 12
                textVerticalOffset: 30
            }

			Connections
            {
                target: mainFooter
                onShowHelp: flipPanel.showHelp()
            }
		}
			
			Row
			{
				id: topButtons
				property int tabOrder: 7
				visible: moveSearch.state == "Hide"
				objectName: "topButtons"
                anchors.right: parent.right
                anchors.rightMargin: 15
                anchors.top: parent.top
                anchors.topMargin: 43

                spacing: 10
				TopBarButton
				{
					id: news
					objectName: "NewsButton"
					iconImage: "../images/main_window/topbar/News.png"
					onClicked: { innersView.show("panelNewsList"); }
                    visible: { MainWindow.startPage.AllNewsCount > 0; }
				}

				TopBarButton
				{
					id: myAccount
					objectName: "MyAccountButton"
					iconImage: "../images/main_window/topbar/MyAccount.png"
					onClicked: { MainWindow.MyAccountAction.Invoke(); }
				}
			}
			
		InnersView
		{
			id: innersView
			objectName: "innersView"
			enabled: opacity == 1

			onOpacityChanged:
			{
				if (opacity == 0)
					dashboard.onNavigateTo()
			}
		}
	
		Item
		{
			id: topLayer
			objectName: "TopLayer"
			enabled: !innersView.animationRunning
            anchors.fill: parent

			Widgets.Button
			{
                id: windowButtons
                property int tabOrder: 8
                objectName: "WindowButtons"
                anchors.right: parent.right
                anchors.rightMargin: 9
                anchors.top: parent.top
                width: childrenRect.width
                height: childrenRect.height
                Row
                {
                    spacing: 0
                    objectName: "WindowButtonsRow"

                    Widgets.KeyNavigation
                    {
                        id: windowButtonsKeyNavigations

                        Component.onCompleted:
                        {
                            var items = [
                                searchButton,
                                minimizeButton,
                                closeButton];
                            focusedItems = items;
                        }
                    }
                    Keys.onRightPressed: windowButtonsKeyNavigations.onSetNext(event)
                    Keys.onLeftPressed: windowButtonsKeyNavigations.onSetPrevious(event)
                    Widgets.Button
                    {
                        property bool searchMode: innersView.get("panelSearch") == innersView.getCurrent()
                        property string prefix: "../images/window/windowbutton_search_";
                        objectName: "Search"
                        tabOrder: 0
                        setFocusOnPressed: true
                        focus: true
                        id: searchButton
                        iconImage: searchMode ? prefix + "pressed.png" : prefix + "normal.png"
                        iconHoverImage: searchMode ? prefix + "pressed.png" : prefix + "hover.png"
                        iconPressedImage: searchMode ? prefix + "pressed.png" : prefix + "normal.png"
                        mirror: Window.Mirror
                        onClicked:
                        {
                            var showed = innersView.getCurrent() == innersView.get("panelSearch")
                            if (showed)
                                innersView.back()
                            else
                                innersView.show("panelSearch")
                        }
                    }
                    Widgets.Button
                    {
                        tabOrder: 0
                        setFocusOnPressed: true
                        id: minimizeButton
                        objectName: "Minimize"
                        iconImage: "../images/window/windowbutton_minimize2_normal.png"
                        iconHoverImage: "../images/window/windowbutton_minimize2_hover.png"
                        iconPressedImage: "../images/window/windowbutton_minimize2_pressed.png"
                        mirror: Window.Mirror
                        onClicked: Window.Minimize()
                    }
                    Widgets.Button
                    {
                        tabOrder: 0
                        setFocusOnPressed: true
                        id: closeButton
                        objectName: "Close"
                        iconImage: "../images/window/windowbutton_close_normal.png"
                        iconHoverImage: "../images/window/windowbutton_close_hover.png"
                        iconPressedImage: "../images/window/windowbutton_close_pressed.png"
                        mirror: Window.Mirror
                        onClicked: Window.Close()
                    }
                }
            }

            Item
			{
				objectName: "Search"
                anchors.right: topButtons.right
                anchors.rightMargin: 1
				anchors.bottom: topButtons.bottom
				anchors.bottomMargin: 9
				width: moveSearch.width
				height: moveSearch.height
				clip: true
				SlidePanel
				{
					id: moveSearch
					objectName: "SlidePanel"
					anchors.right: parent.right
					anchors.rightMargin: -430
					onHide:-parent.height
					onShow:0

					width: 638;
					height: search.height;
					color: "transparent"

					property alias text: search.text
					property bool slidePanelAnimatationRunning: false
					property bool searchActivated: slidePanelAnimatationRunning && enabled && (state == "Show")
					onAnimationStarted: slidePanelAnimatationRunning = false
					onAnimationFinished: slidePanelAnimatationRunning = true
					onSearchActivatedChanged:
					{
						if (searchActivated)
							search.setActiveFocus();
					}

					SearchBox
					{
						id: search
						onTextChanged:
						{
							var panel = innersView.get("panelSearch").item;
							if (panel)
								panel.updateSearchList(moveSearch.text);
							search.sfocus = true
						}
					}
				}
			}

		}
        Component.onCompleted: mainView.forceActiveFocus()
	}
	Widgets.DPIScaler
	{
		id: dpiScaler
		changeSize: true
		widthProperty: "panelWidth"
		heightProperty: "panelHeight"
	}
	function showHelp()
	{
		var helpId = (flipPanel.isFlipped() ? backView : mainView).getHelpId();
		if (helpId)
			Help.Show(helpId);
	}
	Keys.onPressed:
	{
		if (event.key == Qt.Key_F1)
			showHelp();
		else if (event.key == Qt.Key_Escape)
		{
			if (flipPanel.isFlipped())
				backView.closePage();
			else
				Window.Close();
		}
		else 
			event.accepted = false;
	}
}
