import QtQuick 1.1
import QtWidgetProxies 1.0

import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../../common/ProductTypeHelper.js" as ProductTypeHelper
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    id: settingsPage
    objectName: "Protection"

    property int helpId: HelpMapper.GeneralSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "General")
    property variant fontStyles: Fonts.Common{}

    Localizer { id: tr; scope: "GeneralSettings" }

    Column
    {
        objectName: "MainWrapper"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "GeneralMainSection"
            body: Column
            {
                objectName: "GeneralMain"
                spacing: Margins.settingsMainSectionSpacing

                SettingsCommon.SettingsStandardText
                {
                    width: parent.width
                    text: tr.Localize("Description_" + ProductTypeHelper.productTypeToString(context))
                    wrapMode: Text.Wrap
                    anchors.left: parent.left
                }

                SettingsCommon.CheckBox
                {
                    objectName: "EnableProtection"
                    text: tr.Localize("EnableProtection")
                    isBold: true
                    visible: context.protectionInstalled
                    target: context
                    property: "enableProtection"
                    anchors.left: parent.left
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "Interaction"
            name: tr.Localize("InteractionSection")
            body: Column
            {
                spacing: Margins.settingsCheckboxSpacing

                SettingsCommon.CheckBox
                {
                    id: disableInteraction

                    objectName: "DisableInteraction"
                    text: tr.Localize("DisableInteraction")
                    target: context
                    property: "disableInteraction"
                    anchors.left: parent.left
                }

                SettingsCommon.CheckBox
                {
                    objectName: "DontDeleteSuspicious"
                    anchors.left: disableInteraction.left
                    anchors.leftMargin: disableInteraction.textMargin
                    text: tr.Localize("DontDeleteSuspicious")
                    target: context
                    property: "dontDeleteSuspicious"
                    enabled: context.disableInteraction
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "Password"
            name: tr.Localize("PasswordSection")
            body: Column
            {
                objectName: "PasswordSettingsWrapper"
                spacing: Margins.settingsBeforeButtonSpacing

                Column
                {
                    objectName: "EnablePasswordWrapper"
                    spacing: Margins.settingsSectionInnerSpacing
                    height: !context.passwordValidity ? childrenRect.height : enablePassword.height
                    width: parent.width

                    SettingsCommon.CheckBox
                    {
                        id: enablePassword
                        objectName: "EnablePassword"
                        text: tr.Localize("EnablePassword")
                        target: context
                        property: "enablePassword"
                        anchors.left: parent.left
                    }

                    SettingsCommon.SettingsStandardText
                    {
                        text: tr.Localize("PasswordSettingsIsNotValid")
                        anchors.left: enablePassword.left
                        anchors.leftMargin: enablePassword.textMargin
                        visible: !context.passwordValidity
                        color: "red"
                    }
                }

                SettingsCommon.SettingsButton
                {
                    objectName: "SetPassword"
                    text: tr.Localize("SettingsMore")
                    enabled: context.enablePassword
                    onClicked: context.OpenPasswordSettings()
                    anchors.left: parent.left
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName:"RunOnStartupSection"
            name: tr.Localize("AutorunSection")
            body: Column
            {
                objectName: "RunOnStartupWrapper"

                SettingsCommon.CheckBox
                {
                    objectName:"RunOnStartup"
                    text: tr.Localize("Autorun_" + ProductTypeHelper.productTypeToString(context))
                    textfont: settingsPage.fontStyles.standardSettingsTextFont
                    target: context
                    property: "autorun"
                    anchors.left: parent.left
                }
            }
        }
    }
}
