import QtQuick 1.1
import "../common/fonts" as Fonts
import "SettingsMargins.js" as Margins
import "../common/ProductTypeHelper.js" as ProductTypeHelper
import "../common/widgets" as Widgets

Item
{
    id: settingsArea
    objectName: "SettingsArea"
    property int helpId : settingsLoader.item && settingsLoader.item.helpId ? settingsLoader.item.helpId : 0
    property string featureName:  ""
    visible: featureName !== ""
    property variant context
    property variant commonFontStyles: Fonts.Common{}

    Item
    {
        objectName: "MarginedSettingsArea"
        anchors
        {
            fill: parent
            leftMargin: 7
            rightMargin: 7
            topMargin: 7
            bottomMargin: 7
        }

        Item
        {
            id: captionRow
            anchors
            {
                left: parent.left
                leftMargin: Margins.settingsAreaLeft
                top: parent.top
                topMargin: 6
            }
            height: caption.height
            width: parent.width

            Row {
                id: caption
                width: parent.width
                height: captionText.height
                anchors.left: parent.left
                anchors.verticalCenter: parent.verticalCenter
                spacing: Margins.settingsAreaLeft
                Text
                {
                    id: captionText
                    horizontalAlignment: Text.AlignLeft
                    wrapMode: Text.WordWrap
                    property string defaultTrKey: featureName + "Long"
                    property string productTrKey: defaultTrKey + "_" + ProductTypeHelper.productTypeToString(context)
                    text: featureName != "" ? tr.LocalizeOptional(productTrKey, defaultTrKey) : ""
                    font: commonFontStyles.standardSettingsCaptionFont
                    color: "#002822"
                    anchors.verticalCenter: parent.verticalCenter
                }

                Widgets.InfoLink
                {
                    anchors.verticalCenter: parent.verticalCenter
                    anchors.verticalCenterOffset: 1

                    url: settingsLoader.item && settingsLoader.item.helpUrl ? settingsLoader.item.helpUrl : ""
                    visible: url
                }
            }
        }

        Loader
        {
            id: settingsLoader
            objectName: "Loader"
            property variant context
            anchors
            {
                left: parent.left
                leftMargin: Margins.settingsAreaLeft
                right: parent.right
                rightMargin: Margins.settingsAreaRight
                top: captionRow.bottom
                topMargin: Margins.settingsAreaTop
                bottom: parent.bottom
            }
            source: featureName === "" ? "" : featureName + "/SettingsPage.qml"
        }
    }
}
