import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../common/Margins.js" as Margins

Item
{
    id: setPassword
    anchors.fill: parent
    objectName: "SetPassword"

    Localizer { id:tr; scope:"ParentalControl" }

    property variant context: MainWindow.GetSubViewModel("ParentalControl")
    property string error: ""
    property variant commonFontStyles: Fonts.Common{}
    property variant isPasswordEntered: false
    property bool pressShortcutFromEdit : false
    property variant lastItemInFocus

    Keys.onReleased:
    {
        if (event.modifiers & Qt.AltModifier)
        {
            pressShortcutFromEdit = true;
            return;
        }
        if ((event.key == Qt.Key_Alt) && !pressShortcutFromEdit)
        {
            lastItemInFocus.setActiveFocus();
        }
        pressShortcutFromEdit = false;
    }

    function setActiveFocus()
    {
        newPassword.setActiveFocus();
    }
    
    Component.onCompleted:
    {
        newPassword.focus = true
    }

    Widgets.StandardCaptionText
    {
        id: header
        y: 100
        anchors.horizontalCenter: parent.horizontalCenter
        text: tr.Localize("PasswordProtection")
    }

    Text
    {
        id: description
        anchors.top: header.bottom
        anchors.topMargin: Margins.verticalCaptionToCommonText
        anchors.horizontalCenter: parent.horizontalCenter
        horizontalAlignment: Text.AlignHCenter
        width:  parent.width - 300
        text: tr.Localize("PasswordProtectionDescription")
        font: commonFontStyles.standardCommonTextFont
        color: "black"
        wrapMode: Text.Wrap
        lineHeight: Margins.commonTextLineHeight
    }

    Column
    {
        anchors
        {
            top: description.bottom;
            left: parent.left;
            horizontalCenter: parent.horizontalCenter
        }
        width:  parent.width - 300
        spacing: Margins.verticalCommonTextToWidget

        TextEditBox
        {
            id: newPassword
            anchors.right: buttonsGroup.right
            editWidth: buttonsGroup.width
            dialogParent: setPassword
            width:  parent.width
            descriptioText: tr.Localize("Password")
            target: context.PasswordSet
            targetProperty: "Password"
            Keys.onEnterPressed: newPassword.clicked(event)
            Keys.onReturnPressed: newPassword.clicked(event)
            function clicked(event)
            {
                if (editText.length && !confirmation.editText.length)
                    confirmation.setActiveFocus()
                else
                    event.accepted = false;
            }
            Keys.onPressed: setPassword.lastItemInFocus = newPassword;
        }
        TextEditBox
        {
            id: confirmation
            anchors.right: buttonsGroup.right
            editWidth: buttonsGroup.width
            dialogParent: setPassword
            width:  parent.width
            descriptioText: tr.Localize("Confirm")
            target: context.PasswordSet
            targetProperty: "PasswordConfirmation"
            Keys.onPressed: setPassword.lastItemInFocus = confirmation;
        }

        Row
        {
            objectName: "buttonsGroup"
            id: buttonsGroup
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.topMargin: 18

            spacing: Margins.horizontalBetweenButtons

            Widgets.GrayButton
            {
                id: createPasswordButton
                objectName: "CreatePasswordButton"
                text: tr.Localize("Continue")
                enabled: newPassword.editText.length > 0
                setAsDefaultButton: enabled
                onClicked:
                {
                    isPasswordEntered = context.PasswordSet.IsPasswordConfirmed

                    if (context.PasswordSet.IsPasswordConfirmed)
                    {
                        error = ""
                    }
                    else
                    {
                        error = tr.Localize("PasswordNotConfirmed")
                    }
                }
            }

            Widgets.GrayButton
            {
                id: showPasswordGroupDialogButton
                objectName: "SetPasswordGroupButton"
                text: tr.Localize("SkipButton")
                onClicked:
                {
                    context.PasswordSet.IsPasswordSkiped = true
                }
            }
        }


        Text
        {
            anchors.topMargin: 20
            anchors.horizontalCenter: parent.horizontalCenter
            text: error
            font: commonFontStyles.standardCommonTextFont
            color: "red"
        }
    }
}
