import QtQuick 1.1
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets

Item
{
	id:		serialNumber
	objectName: "serialNumber"
	width: 	rowOfElements.width
	height:	rowOfElements.height

	property int elementWidth:	53
	property int elementHeight:	24
	property int spacing:		20 * scaler.factor
	property int maxSymbolCount:5
	property int tabOrder: 1

	property variant	fontStyles: Fonts.LicenseFonts{}
	property string		serialNumberText
	property alias text: serialNumber.serialNumberText
		
	property bool inputActiveFocus: e1.inputActiveFocus || e2.inputActiveFocus || e3.inputActiveFocus || e4.inputActiveFocus

	property string highlightColor: "#eabd06"

	signal serialNumberChanged(bool acceptable)
	
	Widgets.DPIScaler
	{ 
		id: scaler;
		widthProperty: "elementWidth"
		heightProperty: "elementHeight"

		changeSize: true;
	}

	states: [
		State
		{
			name: "highlight"
			PropertyChanges { target: e1; border.color: highlightColor}
			PropertyChanges { target: e2; border.color: highlightColor}
			PropertyChanges { target: e3; border.color: highlightColor}
			PropertyChanges { target: e4; border.color: highlightColor}
		}
	]
	
	transitions: [
		Transition 
		{
			NumberAnimation { property: "border.color"; easing.type: Easing.OutElastic; duration:50 }
		}
	]

	// interface functions
	function isFull()
	{
		for (var index = 0; index < listElements.count; index++)
		{
			var element = listElements.get(index).element
			if (element.text.length != element.maxSymbolCount)
				return false
		}
		return true;
	}
	
	function setFocus()
	{
		if (!listElements.count)
			return;

		var element = listElements.get(lastFocusedElementIndex).element

		for (var index = 0; index < listElements.count; index++)
		{
			var currentElement = listElements.get(index).element;
			if (currentElement.inputFocus)
			{
				element = currentElement;
				break;
			}
		}

		if (!element.inputActiveFocus)
			element.setInputFocus();
	}
	function setFocusOff()
	{
		for (var index = 0; index < listElements.count; index++)
		{
			var currentElement = listElements.get(index).element;
			if (currentElement.inputActiveFocus)
				lastFocusedElementIndex = index;
			listElements.get(index).element.inputFocus = false;
		}
	}
	property int lastFocusedElementIndex: 0

	// internal functions
	function collectSerialNumber()
	{
		var text = "";
		for (var index = 0; index < listElements.count; index++)
			text = text + listElements.get(index).element.text + ((index == (listElements.count - 1)) ? "" : "-")
		return text;
	}
	
	function clearSerialNumber()
	{
		for (var index = 0; index < listElements.count; index++)
		{
			listElements.get(index).element.text = "";
		}
		listElements.get(0).element.setFocus(false,0);
	}
	
	onSerialNumberTextChanged:
	{
		var collectedSerialNumberText = collectSerialNumber();
		if (collectedSerialNumberText != serialNumberText && listElements.count)
		{
			clearSerialNumber();
			listElements.get(0).element.text = serialNumberText;
	}
	}

	ListModel{id: listElements}
	function addSerialNumberElement(element)
	{
		if (listElements.count)
		{
			var previosElement = listElements.get(listElements.count - 1).element;
			previosElement.nextElement = element;
			element.previousElement = previosElement;
		}
		listElements.append({"element": element});
	}
	function changeSerialNumberText()
	{
		var newSerialNumberText = collectSerialNumber();
		if (isFull() && (newSerialNumberText != serialNumberText))
			serialNumberText = newSerialNumberText;
	}
	Row
	{
		id: rowOfElements
		SerialNumberElement{id: e1; objectName: "element1"}
		SerialNumberSpacing{}
		SerialNumberElement{id: e2; objectName: "element2"}
		SerialNumberSpacing{}
		SerialNumberElement{id: e3; objectName: "element3"}
		SerialNumberSpacing{}
		SerialNumberElement{id: e4; objectName: "element4"}
	}
	Component.onCompleted:
	{
		addSerialNumberElement(e1);
		addSerialNumberElement(e2);
		addSerialNumberElement(e3);
		addSerialNumberElement(e4);
		if (serialNumberText)
			serialNumberTextChanged();
	}
}
