import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/fonts" as Fonts
import "../common/widgets" as Widgets

Item {
	id: mainFooter
	objectName: "MainFooter"
	property variant fontStylesFont: Fonts.Fonts{}
	property color textColor
	property color textcolorHovered: textColor
	property color textcolorPressed: textcolorHovered
    property string focusSource
	
	Localizer { id:tr; scope:"MainWindow" }

	property int tabOrder: 1
	
	signal showHelp

	Component
	{
		id: mainFooterButton
		Widgets.Button
		{
			textfont: fontStylesFont.footerFont;
			textcolor: mainFooter.textColor
			textcolorHovered: mainFooter.textcolorHovered
			textcolorPressed: mainFooter.textcolorPressed
            textcolorDisabled: mainFooter.textColor
            focus: true
			text: parent.text
			onClicked: parent.action()
			objectName: "Button"
			anchors.verticalCenter: parent.verticalCenter
			anchors.verticalCenterOffset: mainFooter.shadowAtTop ? 0 : 0
            focusRectEnabled: false

            Widgets.FocusImage
            {
                anchors.verticalCenter: parent.verticalCenter
                anchors.verticalCenterOffset: 1
                anchors.horizontalCenter: parent.horizontalCenter
                tileHorizontally: true
                widthClipperSize: -14
                border {
                    left: 13
                    right: 15
                }
                source: mainFooter.focusSource
            }
		}
	}

	Widgets.KeyNavigation
	{
		id: keyNavigations

		Component.onCompleted:
		{
			var items = [
				help,
				support,
				myAccount,
				license
			];
			focusedItems = items;
		}
	}
	Keys.onRightPressed: keyNavigations.onSetNext(event)
	Keys.onLeftPressed: keyNavigations.onSetPrevious(event)

	Row
	{
		id: leftRow
		objectName: "LeftRow"
		anchors.left: parent.left
        anchors.leftMargin: 20
		anchors.verticalCenter: parent.verticalCenter
        anchors.verticalCenterOffset: -2
        spacing: 19
		Loader
		{
			objectName: "Help"
			id: help
			sourceComponent: mainFooterButton
			property string text: tr.Localize("Help")
			function action(){mainFooter.showHelp();}
		}
		Loader
		{
			objectName: "Support"
			id: support
			sourceComponent: mainFooterButton
			property string text: tr.Localize("Support")
            function action() { MainWindow.InvokeSkinAction("window(\"QMLSupport\")") }
		}
		Loader
		{
			objectName: "MyAccount"
			id: myAccount
			sourceComponent: mainFooterButton
			property string text: tr.Localize("MyAccount")
			function action() { MainWindow.MyAccountAction.Invoke(); }
		}
	}

	Loader
	{
		objectName: "License"
		id: license
		sourceComponent: mainFooterButton
		anchors.right: parent.right
        anchors.rightMargin: 15
		y: leftRow.y
		property string text: MainWindow.shouldLocalizeLicenseButtonText ? tr.Localize(MainWindow.licenseButtonText) : MainWindow.licenseButtonText;
		function action() { MainWindow.ShowLicenseManagerAction.Invoke(); }
	}
}
