import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/EnumHelper.js" as EnumHelper
import "../common/widgets" as Widgets


Widgets.Button
{
    id: button
    objectName: component.ComponentType;
    tabOrder: 0
    signal activate(string panelName)
    signal rightPressed
    signal leftPressed
    signal downPressed
    signal upPressed
    focus: ListView.view != null && ListView.view.focusIndex == index && button.enabled
    focusRectEnabled: false
    setFocusOnPressed: true

    horizontalMargin: 5
    verticalMargin: 5
    spacing: 0
    Localizer { id:tr; scope:"MainWindow" }
    text: tr.Localize(component.ComponentType);
    textBottom: true
    iconImage: getComponentImage(component.ComponentType);
    hoverEffectImage: "../images/main_window/featurebox/hover.png"
    textcolor: "#ffffff"
    textcolorDisabled: "#ffffff"
    textfont.family: "FranklinGothicMediumTT"
    textfont.pointSize: 10
    textWidth: 150

    Widgets.FocusRect
    {
        anchors.leftMargin: 10
        anchors.rightMargin: 10
        anchors.bottomMargin: 20
        anchors.topMargin: 15
    }

    property variant context: MainWindow
    property variant component: model.modelData
    property bool defaultArrowsProcessing: true
    function getImageSuffix(componentType)
    {
        switch (componentType)
        {
            case "Scan": return "01";
            case "ProgramsActivity": return "03";
            case "Updater": return "04";
            case "SafeProgramsStartup": return "05";
            case "NetworkMonitoring": return "06";
            case "VirtualKeyboard": return "07";
            case "PersonalDataProtection": return "09";
            case "Quarantine": return "10";
            case "Tools": return "11";
            case "SafeWebSitesBrowsing": return "13";
            case "Upgrade": return "12";
            case "Downgrade": return "12";
            case "SafeBanking": return "14";
            default: return "";
        }
    }

    function getComponentImage(componentType)
    {
        var suffix = getImageSuffix(componentType)
        var prefix = (suffix === "") ? "../images/main_window/featurebox/icons_" : "../images/main_window/featurebox/icons_";
        suffix = (suffix === "") ? componentType : suffix;
        return prefix + suffix + ".png";
    }

    onClicked:
    {
        if (Qt.isQtObject(component.Action))
            component.Action.Invoke();
        else
            button.activate("panel" + component.ComponentType);
    }

    onPressed:
    {
        if (activeFocus)
        {
            if (ListView.view && ListView.view.focusIndex != index)
                ListView.view.focusIndex = index;
            if (GridView.view && GridView.view.currentIndex != index)
                GridView.view.currentIndex = index;
        }
    }
    Keys.onRightPressed:
    {
        button.rightPressed();
        event.accepted = !button.defaultArrowsProcessing;
    }
    Keys.onLeftPressed:
    {
        button.leftPressed();
        event.accepted = !button.defaultArrowsProcessing;
    }
    Keys.onDownPressed:
    {
        button.downPressed();
        event.accepted = !button.defaultArrowsProcessing;
    }
    Keys.onUpPressed:
    {
        button.upPressed();
        event.accepted = !button.defaultArrowsProcessing;
    }
}
