import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/EnumHelper.js" as EnumHelper
import "../common/widgets" as Widgets

Widgets.WizardPage
{
	Localizer { id:tr; scope:"MigrationWizard" }
    context: MainWindow.migrationWizard
    wizardState: context.CurrentPage
    wizardStateName: "CurrentPage"
    
    function getMigrationType()
    {
		switch(EnumHelper.getKey(context, "MigrationType"))
		{
		case "KasperskyInternetSecurity":
			return tr.Localize("MigrationKis");
		case "KasperskyAntiVirus":
			return tr.Localize("MigrationKav");
		default:
			return tr.Localize("MigrationUnknown");
		}
    }
    
    function getPageHeader()
    {
		switch(EnumHelper.getKey(context, "CurrentPage"))
		{
		case "WizardBegin":
		case "MigrationProgress":
		case "WizardContinue":
			return getMigrationType();
		case "SearchSafeRemovalApplications":
		case "SearchManualRemovalApplications":
		case "SearchUnsafeRemovalApplications":
			return tr.Localize("SearchRemovalApplicationsHeader");
		case "SafeRemovalApplications":
		case "ManualRemovalApplications":
		case "UnsafeRemovalApplications":
			return tr.Localize("RemovalApplicationsHeader");
		case "SafeRemovalProgress":
		case "UnsafeRemovalProgress":
			return tr.Localize("RemovalProgressHeader");
		case "":
			return "";
		default:
			return tr.Localize(EnumHelper.getKey(context, "CurrentPage") + "Header", {"MigrationType" : getMigrationType()});
		}
		return "";
    }

    headerString: getPageHeader()
    
    function getPageDescription()
    {
		if(context.CurrentPage === undefined) // For a binding only. CurrentPage is int, 0 is valid value.
			return "";
		switch(EnumHelper.getKey(context, "CurrentPage"))
		{
		case "WizardBegin":
			{
				switch(EnumHelper.getKey(context, "MigrationType"))
				{
				case "KasperskyInternetSecurity":
					return tr.Localize("WizardBeginDescriptionKis")
					+ (context.CouldReturn ? "" : tr.Localize("MigrationNocomebackWarning"));
				case "KasperskyAntiVirus":
					return tr.Localize("WizardBeginDescriptionKav");
				default:
					return tr.Localize("MigrationUnknown");
				}
			}
		case "MigrationProgress":
			{
				switch(EnumHelper.getKey(context, "MigrationType"))
				{
				case "KasperskyInternetSecurity":
					return tr.Localize("WizardContinueDescriptionKis");
				case "KasperskyAntiVirus":
					return tr.Localize("MigrationProgressDescriptionKav");
				default:
					return tr.Localize("MigrationUnknown");
				}
			}
		case "WizardContinue":
			{
				switch(EnumHelper.getKey(context, "MigrationType"))
				{
				case "KasperskyInternetSecurity":
					return tr.Localize("WizardContinueDescriptionKis");
				case "KasperskyAntiVirus":
					return tr.Localize("WizardContinueDescriptionKav");
				default:
					return tr.Localize("MigrationUnknown");
				}
			}
		case "SearchSafeRemovalApplications":
		case "SearchManualRemovalApplications":
		case "SearchUnsafeRemovalApplications":
			return tr.Localize("SearchRemovalApplicationsDescription");
		case "SafeRemovalApplications":
		case "ManualRemovalApplications":
		case "UnsafeRemovalApplications":
			return tr.Localize("RemovalApplicationsDescription");
		case "SafeRemovalProgress":
		case "UnsafeRemovalProgress":
			return tr.Localize("RemovalProgressDescription");
		case "":
			return "";
		default:
			return tr.Localize(EnumHelper.getKey(context, "CurrentPage") + "Description", {"MigrationType" : getMigrationType()});
		}
		return "";
    }

    backButtonEnabled: context.PrevAction != undefined && context.PrevAction.IsEnabled;
    nextButtonEnabled: (context.NextAction != undefined && context.NextAction.IsEnabled) || 
						(context.FinishAction != undefined && context.FinishAction.IsEnabled)
    cancelButtonEnabled: context.CancelAction != undefined && context.CancelAction.IsEnabled;
    helpButtonVisible: false

    function isFinishAvailable()
    {
        return context.FinishAction != undefined && context.FinishAction.IsEnabled;
    }
    
    function finishWizard()
    {
		parentWizard.close()
	}

    nextButtonText: isFinishAvailable() ?
            tr.Localize("FinishButton") : tr.Localize("NextButton");

    function onNext()
    {
        if (isFinishAvailable())
        {
            if (context.FinishAction != undefined)
                context.FinishAction.Invoke();
			finishWizard();
        }
        else
        {
            if (context.NextAction != undefined)
                context.NextAction.Invoke();
        }
    }

    function onBack()
    {
        if (context.PrevAction != undefined)
            context.PrevAction.Invoke();
    }
    function onCancel()
    {
        if (context.CancelAction != undefined)
            context.CancelAction.Invoke();
    }
    function onClose()
    {
        if (context.CancelAction != undefined)
            context.CancelAction.Invoke();
    }
    
}

