import QtQuick 1.1
import QtWidgetProxies 1.0
import "../common/Common.js" as Common
import "../common/widgets" as Widgets
import "../common/fonts" as Fonts
import "../main_window" as MainFrame
import "../common/HelpMapper.js" as HelpMapper

MainFrame.InnerContent
{
	Localizer { id:tr; scope:"MainWindow" }
	caption: tr.Localize("UpgradeProduct")
    property int helpId: HelpMapper.MigrationUpgradeHelpId
	objectName: "upgradeProduct"

	viewArea: Component
	{
		Item
		{
			property variant commonFontStyles: Fonts.Common{}
			property variant context: MainWindow
			objectName: "viewArea"

			Column
			{
				objectName: "column"
				anchors.top: parent.top;
                anchors.topMargin: 25
				anchors.left: parent.left
				anchors.leftMargin: 30
				anchors.right: parent.right
				anchors.rightMargin: 30

				Widgets.StandardCaptionText
				{
					id: header
                    text: tr.Localize("ProductName_KIS_Full")
					horizontalAlignment: Text.AlignLeft
					anchors.left: parent.left
					anchors.right: parent.right
					wrapMode: Text.WordWrap
				}

                Item { width: parent.width; height: 6 }

				BorderImage
				{
					source: "../common/images/widgets/separator_horz.png"
					horizontalTileMode: BorderImage.Repeat
					width: parent.width
				}

                Item { width: parent.width; height: 8 }

				Text
				{
                    text: tr.Localize("UpgadeToKISHint")
					font: commonFontStyles.standardCommonTextFont
					width: parent.width
					wrapMode: "WordWrap"
					horizontalAlignment: Text.AlignLeft
				}
				
                Item { width: parent.width; height: 2 }

				Image
				{
					source: "../common/images/widgets/upgrade_items.png"
                    Widgets.DPIScaler { changeSize: true }
                    mirror: Window.Mirror

					function itemXPosition( itemX )
					{
						if( mirror ) return width - itemX;
						else return itemX;
					}

					Item
					{
						x: parent.itemXPosition(128)
						y: 81
						Text
						{
							anchors.centerIn: parent
							font: commonFontStyles.standardCommonTextFont
							text: tr.Localize("ApplicationControl");
							smooth: true
						}
                        Widgets.DPIScaler { changePlace: true }
					}
					Item
					{
						x: parent.itemXPosition(305)
						y: 81
						Text
						{
							anchors.centerIn: parent
							font: commonFontStyles.standardCommonTextFont
							text: tr.Localize("ParentalControl");
							smooth: true
						}
                        Widgets.DPIScaler { changePlace: true }
					}
					Item
					{
						x: parent.itemXPosition(487)
						y: 81
						Text
						{
							anchors.centerIn: parent
							font: commonFontStyles.standardCommonTextFont
                            text: tr.Localize("SafeBanking");
							smooth: true
						}
                        Widgets.DPIScaler { changePlace: true }
					}
					Item
					{
						x: parent.itemXPosition(128)
						y: 163
						Text
						{
							anchors.centerIn: parent
							font: commonFontStyles.standardCommonTextFont
							text: tr.Localize("IDS");
							smooth: true
						}
                        Widgets.DPIScaler { changePlace: true }
					}
					Item
					{
						x: parent.itemXPosition(305)
						y: 163
						Text
						{
							anchors.centerIn: parent
							font: commonFontStyles.standardCommonTextFont
							text: tr.Localize("Firewall");
							smooth: true
						}
                        Widgets.DPIScaler { changePlace: true }
					}
					Item
					{
						x: parent.itemXPosition(487)
						y: 163
						Text
						{
							anchors.centerIn: parent
							font: commonFontStyles.standardCommonTextFont
							text: tr.Localize("SecureWirelessConnections");
							smooth: true
						}
                        Widgets.DPIScaler { changePlace: true }
					}

				}
				
                Item { width: parent.width; height: 25 }

				Item
				{
					height: 30
					width: parent.width
					objectName: "buttons"
					
					Widgets.GreenButton
					{
						id: tryKis
						anchors.left: parent.left
						objectName: "TryKis"
						visible: MainWindow.UpgradeToKisAction.IsEnabled;
						text: tr.Localize("TryKis");
						onClicked:
						{
							MainWindow.UpgradeToKisAction.Invoke()
						}
					}

					Widgets.GrayButton
					{
						function getButtonName()
						{
							var customTitle = MainWindow.startPage.upgradeCustomTitle;
							if (customTitle == "")
								customTitle = tr.Localize("BuyProduct");
							return customTitle;
						}
						id: buyLicense
						objectName: "BuyLicense"
						anchors.right: parent.right
						text: getButtonName();
						iconImage: "../images/license/ico_buy_16_gray.png"
						onClicked:
						{
							MainWindow.startPage.UpgradeProduct(Common.buildPath(parent)+"."+buyLicense.objectName)
						}
					}
					
					Widgets.GrayButton
					{
						id: activateCommercial
						objectName: "ActivateCommercial"
						anchors.right: buyLicense.left
                        anchors.rightMargin: 8
						text: tr.Localize("SelectCommercialActivation");
						onClicked:
						{
							MainWindow.online.ActivateProductAction.Invoke()
						}
					}	
				}
			}
		}
	}
}
