import QtQuick 1.1
import QtWidgetProxies 1.0
import "../../common/widgets" as Widgets
import "../../common/fonts" as Fonts
import ".." as SettingsCommon
import "../SettingsMargins.js" as Margins
import "../SettingsHelper.js" as SettingsHelper
import "../../common/HelpMapper.js" as HelpMapper

Item
{
    objectName: "UpdaterSettingsPage"

    property int helpId: HelpMapper.UpdaterSettingsHelpId

    property variant context: SettingsHelper.GetPageContext(Settings, "Updater")
    property variant fontStyles: Fonts.Common{}

    Localizer { id: tr; scope: "UpdaterSettings" }

    Column
    {
        objectName: "UpdaterSettingsPageColumn"
        width: parent.width
        spacing: Margins.settingsPageSpacing

        SettingsCommon.SettingsSection
        {
            objectName: "RunModeAndSourceSection"
            name: tr.Localize("RunModeAndUpdateSource")
            smallTopMargin: true

            body: Column
            {
                spacing: 5
                objectName: "RunModeAndSource"
                width: parent.width

                SettingsCommon.ButtonTextRow
                {
                    id: runMode
                    objectName: "RunMode"
                    minWidth: 0
                    buttonText: tr.Localize("RunMode")
                    onClicked: context.EditRunMode();
                    labelText: context.scheduleDescription
                    anchors.left: parent.left
                }

                SettingsCommon.ButtonTextRow
                {
                    id: updateSource
                    objectName: "UpdateSource"
                    minWidth: 0
                    buttonText: tr.Localize("UpdateSource")
                    labelText: context.defaultUpdateSource ? tr.Localize("Default") : tr.Localize("DefinedByUser")
                    onClicked: context.EditUpdateSource()
                    anchors.left: parent.left
                }

                Component.onCompleted:
                {
                    var maxWidth = Math.max(runMode.buttonWidth, updateSource.buttonWidth);
                    runMode.minWidth = maxWidth;
                    updateSource.minWidth = maxWidth;
                }
            }
        }

        SettingsCommon.SettingsSection
        {
            objectName: "Additional"
            name: tr.Localize("Additional")
            body: Column
            {
                spacing: Margins.settingsSectionInnerSpacing
                objectName: "Column"

                SettingsCommon.CheckBox
                {
                    text: tr.Localize("NotifyWhenUpdatesAndNewVersionsAreAvailable")
                    target: context
                    property: "notifyUpdatesAndNewVersions"
                    anchors.left: parent.left
                }
            }
        }
    }
}
